@@ -1,7 +1,7 @@
 #!/bin/sh
 
-## live-boot(7) - System Boot Scripts
-## Copyright (C) 2006-2013 Daniel Baumann <daniel@debian.org>
+## live-boot(7) - System Boot Components
+## Copyright (C) 2006-2014 Daniel Baumann <mail@daniel-baumann.ch>
 ##
 ## This program comes with ABSOLUTELY NO WARRANTY; for details see COPYING.
 ## This is free software, and you are welcome to redistribute it
@@ -25,18 +25,18 @@ for MANPAGE in en/*
 do
 	SECTION="$(basename ${MANPAGE} | awk -F. '{ print $2 }')"
 
-	sed -i -e "s|^.TH.*$|.TH ${PROGRAM} ${SECTION} ${DATE} ${VERSION} \"Debian Live Project\"|" ${MANPAGE}
+	sed -i -e "s|^.TH.*$|.TH ${PROGRAM} ${SECTION} ${DATE} ${VERSION} \"Live Systems Project\"|" ${MANPAGE}
 done
 
 # European date format
-for _LANGUAGE in de es fr it
+for _LANGUAGE in es fr it
 do
 	if ls po/${_LANGUAGE}/*.po > /dev/null 2>&1
 	then
 		for _FILE in po/${_LANGUAGE}/*.po
 		do
-			sed -i  -e "s|^msgstr .*.2013-.*$|msgstr \"${DAY}.${MONTH}.${YEAR}\"|g" \
-				-e "s|^msgstr .*.2013\"$|msgstr \"${DAY}.${MONTH}.${YEAR}\"|g" \
+			sed -i  -e "s|^msgstr .*.2014-.*$|msgstr \"${DAY}.${MONTH}.${YEAR}\"|g" \
+				-e "s|^msgstr .*.2014\"$|msgstr \"${DAY}.${MONTH}.${YEAR}\"|g" \
 			"${_FILE}"
 		done
 	fi
@@ -47,8 +47,8 @@ if ls po/pt_BR/*.po > /dev/null 2>&1
 then
 	for _FILE in po/pt_BR/*.po
 	do
-		sed -i  -e "s|^msgstr .*.2013-.*$|msgstr \"${DAY}-${MONTH}-${YEAR}\"|g" \
-			-e "s|^msgstr .*-2013\"$|msgstr \"${DAY}-${MONTH}-${YEAR}\"|g" \
+		sed -i  -e "s|^msgstr .*.2014-.*$|msgstr \"${DAY}-${MONTH}-${YEAR}\"|g" \
+			-e "s|^msgstr .*-2014\"$|msgstr \"${DAY}-${MONTH}-${YEAR}\"|g" \
 		"${_FILE}"
 	done
 fi
